@@ -2,7 +2,8 @@
 import logging
 import logging.handlers
 import time
-from fog_lib import get_macs, client_hostname, client_snapin
+import itertools as it
+from fog_lib import get_macs, client_hostname, client_snapin, load_conf
 
 def main():
 	macs = get_macs()
@@ -10,9 +11,10 @@ def main():
 	for mac in macs:
 		logger.info("Detected mac: " + mac)
 	while True:
-		time.sleep(60)
-		map(client_hostname, macs)
-		map(client_snapin, macs)
+		time.sleep(5)
+		for mac in macs:
+			client_hostname(mac)
+			client_snapin(mac, FOG_HOST, SNAPIN_DIR)
 
 if __name__ == '__main__':
 	requests_log = logging.getLogger("requests")
@@ -28,4 +30,7 @@ if __name__ == '__main__':
 	handler.setFormatter(formatter)
 	logger.addHandler(handler)
 
+	conf = load_conf('/etc/fog_client.ini')
+	fog_host = conf.get("GENERAL", "fog_host")
+	snapin_dir = conf.get("GENERAL","snapin_dir")
 	main()
